launch_execution_node

Function launch_execution_node 

pub async fn launch_execution_node<P: AsRef<Path>>(
    runtime: Runtime,
    chain_spec: TempoChainSpec,
    datadir: P,
    config: ExecutionNodeConfig,
    database: DatabaseEnv,
    rocksdb: Option<RocksDBProvider>,
) -> Result<ExecutionNode>
Launches a tempo execution node.

Difference compared to starting the node through the binary:

  1. faucet is always disabled
  2. components are not provided (looking at the node command, the components are not passed to it).
  3. consensus config is not necessary